/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* global window, document*/

/**
 * Application common page module.
 * Provides common methods related to navigation between pages.
 *
 * @module app.common.pages
 * @requires {@link app.common.events}
 * @namespace app.common.pages
 * @memberof app.common
 */

// make sure that "app" namespace is created
window.app = window.app || {};

// strict mode wrapper function
(function defineAppCommonPages(app) {
    'use strict';

    /**
     * Common events module reference.
     *
     * @memberof app.common.pages
     * @private
     * @type {object}
     */
    var commonEvents = app.common.events,

        /**
         * Active CSS class.
         *
         * @memberof app.common.pages
         * @private
         * @const {string}
         */
        ACTIVE_CLASS = 'active';

    /**
     * Makes the given page active.
     *
     * @memberof app.common.pages
     * @public
     * @param {string} pageId
     * @param {object} [data]
     * @fires "pagehide"
     * @fires "pageshow"
     */
    function changePage(pageId, data) {
        var activePage = document.querySelector('.page.active'),
            destinationPage = document.getElementById(pageId);

        if (activePage && destinationPage) {
            activePage.classList.remove(ACTIVE_CLASS);
            destinationPage.classList.add(ACTIVE_CLASS);
            commonEvents.dispatchEvent('pagehide', data, activePage);
            commonEvents.dispatchEvent('pageshow', data, destinationPage);
        }
    }

    app.common = app.common || {};
    app.common.pages = {
        changePage: changePage
    };

})(window.app);
