/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* global window*/

/**
 * Application common strings module.
 * Provides common methods that allow the application to operate on strings.
 *
 * @module app.common.strings
 * @namespace app.common.strings
 * @memberof app.common
 */

// make sure that "app" namespace is created
window.app = window.app || {};

// strict mode wrapper function
(function defineAppCommonStrings(app) {
    'use strict';

    /**
     * Returns string with escaped HTML special characters.
     *
     * @memberof app.common.strings
     * @public
     * @param {string} string
     * @returns {string}
     */
    function escapeHTML(string) {
        return string
            .replace(/&/g, '&amp;')
            .replace(/</g, '&lt;')
            .replace(/>/g, '&gt;')
            .replace(/"/g, '&quot;')
            .replace(/'/g, '&#039;');
    }

    /**
     * Returns string with escaped single quote characters.
     *
     * @memberof app.common.strings
     * @public
     * @param {string} string
     * @returns {string}
     */
    function escapeSingleQuote(string) {
        return string
            .replace(/'/g, '\\\'');
    }

    /**
     * Returns string if given value is not an empty string.
     * Otherwise it returns null.
     *
     * @memberof app.common.strings
     * @public
     * @param {string} value
     * @returns {string|null}
     */
    function nullIfEmptyString(value) {
        return value !== '' ? value : null;
    }

    app.common = app.common || {};
    app.common.strings = {
        escapeHTML: escapeHTML,
        escapeSingleQuote: escapeSingleQuote,
        nullIfEmptyString: nullIfEmptyString
    };

})(window.app);
