/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* global window*/

/**
 * Application common validation module.
 * Provides common methods that allow the application to validate data
 * describing notification.
 *
 * @module app.common.validation
 * @requires {@link app.model.notification}
 * @namespace app.common.validation
 * @memberof app.common
 */

// make sure that "app" namespace is created
window.app = window.app || {};

// strict mode wrapper function
(function defineAppCommonValidation(app) {
    'use strict';

    /**
     * Model notification module reference.
     *
     * @memberof app.common.validation
     * @private
     * @type {object}
     */
    var modelNotification = app.model.notification;

    /**
     * Checks whether notification is ready to send.
     *
     * Returns true when all required data are entered by the user,
     * false otherwise.
     *
     * @memberof app.common.validation
     * @public
     * @returns {boolean}
     */
    function isReadyToSend() {
        return modelNotification.getTitle() !== '' ? true : false;
    }

    app.common = app.common || {};
    app.common.validation = {
        isReadyToSend: isReadyToSend
    };

})(window.app);
